import logging
import shutil

from linky.config import read_conf
from linky.utils import path_utils


def remove(path):
    """
    Permanently removes a file or directory from linky management

    @param path: What we're trying to delete
    @type path: Path
    """
    logger = logging.getLogger("actions.remove")
    logger.debug("Removing: %s", path)
    config = read_conf(path)
    base_path = config.base_path
    logger.debug("Base path: %s", base_path)

    path_in_base = path_utils.get_path_in_base(base_path, path, config.categories.keys())
    other_paths = path_utils.get_paths_in_root(path_in_base, config)

    for other_path in other_paths + [path_in_base]:
        if other_path.is_symlink() or other_path.is_file():
            other_path.unlink()
        elif other_path.is_dir():
            shutil.rmtree(other_path)
        logger.info("Removed %s", other_path)

        # Make sure to remove empty parent directories
        path_utils.del_empty_parents(other_path)



import logging

from cliff.command import Command

import linky.utils.path_utils as path_utils
from linky.actions import remove


class RemoveCommand(Command):
    """
    Permanently removes / deletes a file or folder and all its links.
    Warning: This is a NON-REVERSIBLE action!
    """

    def get_parser(self, prog_name):
        parser = super(RemoveCommand, self).get_parser(prog_name)
        parser.add_argument("paths", nargs="+", type=path_utils.abs_path,
                            help="The file or directory to remove")
        return parser

    def take_action(self, parsed_args):
        _log = logging.getLogger("command.remove")
        for _abs_path in parsed_args.paths:
            if _abs_path.exists():
                try:
                    remove(_abs_path)
                # pylint:disable=broad-except
                except Exception as exception:
                    _log.error("Couldn't remove '%s': %s",
                               _abs_path, exception,
                               exc_info=True)
            else:
                _log.info("Ignored nonexistent: %s", _abs_path)
